#========================================================================================
# package      DE_EPAGES::AmazonPayments::API::Constants
# state        private
# description  constants for cartridge
#========================================================================================
package DE_EPAGES::AmazonPayments::API::Constants;
use base Exporter;
use strict;
our @EXPORT_OK = qw (
    STATUS_SUCCESS
    STATUS_FAILED
    CREDENTIALS_OK
    CREDENTIALS_UNKNOWN_MERCHANT_ID
    CREDENTIALS_UNAUTHORIZED_DEVELOPER
    ORDER_DRAFT
    ORDER_OPEN
    ORDER_SUSPENDED
    ORDER_CANCELED
    ORDER_CLOSED
    AUTHORIZATION_PENDING
    AUTHORIZATION_OPEN
    AUTHORIZATION_DECLINED
    AUTHORIZATION_CLOSED
    CAPTURE_PENDING
    CAPTURE_COMPLETED
    CAPTURE_DECLINED
    CAPTURE_CLOSED
    AMAZON_REGION_DE
    AMAZON_REGION_UK
    AMAZON_REGION_US
    AMAZON_REGIONS
    AMAZON_SANDBOX_MODE
    AMAZON_LIVE_MODE
    AMAZON_DE_LANGUAGE
    AMAZON_UK_LANGUAGE
    AMAZON_DE_LANGUAGECODE
    AMAZON_UK_LANGUAGECODE
    AMAZON_WIDGETS
    AMAZON_BUTTON_COLORS
    AMAZON_BUTTON_SIZES
    AMAZON_ORDER_STATUS
    AMAZON_AUTHORIZATION_STATUS
    AMAZON_CAPTURE_STATUS
    IPN_PATH
);

#--- transaction status
use constant STATUS_SUCCESS    => 'SUCCESS';
use constant STATUS_FAILED     => 'FAILED';

use constant CREDENTIALS_OK                     => 'OK';
use constant CREDENTIALS_UNKNOWN_MERCHANT_ID    => 'UNKNOWN_MERCHANT_ID';
use constant CREDENTIALS_UNAUTHORIZED_DEVELOPER => 'UNAUTHORIZED_DEVELOPER';

use constant ORDER_DRAFT     => 'OrderDraft';
use constant ORDER_OPEN      => 'OrderOpen';
use constant ORDER_SUSPENDED => 'OrderSuspended';
use constant ORDER_CANCELED  => 'OrderCanceled';
use constant ORDER_CLOSED    => 'OrderClosed';

use constant AUTHORIZATION_PENDING  => 'AuthorizationPending';
use constant AUTHORIZATION_OPEN     => 'AuthorizationOpen';
use constant AUTHORIZATION_DECLINED => 'AuthorizationDeclined';
use constant AUTHORIZATION_CLOSED   => 'AuthorizationClosed';

use constant CAPTURE_PENDING   => 'CapturePending';
use constant CAPTURE_COMPLETED => 'CaptureCompleted';
use constant CAPTURE_DECLINED  => 'CaptureDeclined';
use constant CAPTURE_CLOSED    => 'CaptureClosed';

use constant AMAZON_REGION_DE => 'DE';
use constant AMAZON_REGION_UK => 'UK';
use constant AMAZON_REGION_US => 'US';

use constant AMAZON_SANDBOX_MODE => 'SANDBOX';
use constant AMAZON_LIVE_MODE    => 'LIVE';

use constant AMAZON_DE_LANGUAGE      => 1;
use constant AMAZON_UK_LANGUAGE      => 2;
use constant AMAZON_DE_LANGUAGECODE  => 'de';
use constant AMAZON_UK_LANGUAGECODE  => 'en';

use constant AMAZON_WIDGETS => {
    (AMAZON_SANDBOX_MODE) => {
        (AMAZON_REGION_DE) => {
            WIDGET_URL => 'https://static-eu.payments-amazon.com/OffAmazonPayments/de/sandbox/js/Widgets.js?sellerId=%s',
            BUTTON_URL => 'https://payments-sandbox.amazon.de/gp/widgets/button?sellerId=%s&size=%s&color=%s',
        },

        (AMAZON_REGION_UK) => {
            WIDGET_URL => 'https://static-eu.payments-amazon.com/OffAmazonPayments/uk/sandbox/js/Widgets.js?sellerId=%s',
            BUTTON_URL => 'https://payments-sandbox.amazon.co.uk/gp/widgets/button?sellerId=%s&size=%s&color=%s',
        },

        (AMAZON_REGION_US) => {
            WIDGET_URL => 'https://static-na.payments-amazon.com/OffAmazonPayments/us/sandbox/js/Widgets.js?sellerId=%s',
            BUTTON_URL => 'https://payments-sandbox.amazon.com/gp/widgets/button?sellerId=%s&size=%s&color=%s',
        },
    },

    (AMAZON_LIVE_MODE) => {
        (AMAZON_REGION_DE) => {
            WIDGET_URL => 'https://static-eu.payments-amazon.com/OffAmazonPayments/de/js/Widgets.js?sellerId=%s',
            BUTTON_URL => 'https://payments.amazon.de/gp/widgets/button?sellerId=%s&size=%s&color=%s',
        },

        (AMAZON_REGION_UK) => {
            WIDGET_URL => 'https://static-eu.payments-amazon.com/OffAmazonPayments/uk/js/Widgets.js?sellerId=%s',
            BUTTON_URL => 'https://payments.amazon.co.uk/gp/widgets/button?sellerId=%s&size=%s&color=%s',
        },

        (AMAZON_REGION_US) => {
            WIDGET_URL => 'https://static-na.payments-amazon.com/OffAmazonPayments/us/js/Widgets.js?sellerId=%s',
            BUTTON_URL => 'https://payments.amazon.com/gp/widgets/button?sellerId=%s&size=%s&color=%s',
        },
    },
};

use constant AMAZON_REGIONS => {
    (AMAZON_REGION_DE) => {
        COUNTRY_CODE => 'DE',
        CURRENCIES   => [qw( EUR )],
        LANGUAGES    => [qw( de )],
    },

    (AMAZON_REGION_UK) => {
        COUNTRY_CODE => 'GB',
        CURRENCIES   => [qw( GBP )],
        LANGUAGES    => [qw( en )],
    },
};

use constant AMAZON_BUTTON_COLORS => [qw(
    orange
    tan
)];

use constant AMAZON_BUTTON_SIZES => [qw(
    medium
    large
    x-large
)];

use constant AMAZON_ORDER_STATUS => {
    (ORDER_DRAFT)      => 'Draft',
    (ORDER_OPEN)       => 'Open',
    (ORDER_SUSPENDED)  => 'Suspended',
    (ORDER_CANCELED)   => 'Canceled',
    (ORDER_CLOSED)     => 'Closed',
};

use constant AMAZON_AUTHORIZATION_STATUS => {
    (AUTHORIZATION_PENDING)   => 'Pending',
    (AUTHORIZATION_OPEN)      => 'Open',
    (AUTHORIZATION_DECLINED)  => 'Declined',
    (AUTHORIZATION_CLOSED)    => 'Closed',
};

use constant AMAZON_CAPTURE_STATUS => {
    (CAPTURE_PENDING)     => 'Pending',
    (CAPTURE_COMPLETED)   => 'Completed',
    (CAPTURE_DECLINED)    => 'Declined',
    (CAPTURE_CLOSED)      => 'Closed',
};

use constant IPN_PATH => 'payments/amazon/callback/';

1;