#========================================================================================
# package      DE_EPAGES::AmazonPayments::UI::Shop
# state        private
# description  UI class
#========================================================================================
package DE_EPAGES::AmazonPayments::UI::Shop;
use base DE_EPAGES::Order::UI::Shop;
use DE_EPAGES::Object::API::Factory qw (LoadRootObject);
use DE_EPAGES::Object::API::Table::Language qw( GetInfoLanguagesByCode2 );
use DE_EPAGES::AmazonPayments::API::Constants qw ( AMAZON_DE_LANGUAGECODE AMAZON_UK_LANGUAGECODE );
use strict;

#========================================================================================
# function     TransactionPaymentName
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Name = $Handler->TransactionPaymentName();
#----------------------------------------------------------------------------------------
# description  return name of PaymentType for search/view transactions.
#----------------------------------------------------------------------------------------
# return       $Name | name of payment type | string
#========================================================================================
sub TransactionPaymentName {'AmazonPayments'}

sub ViewTransactions {
    my $self      = shift;
    my ($Servlet) = @_;

    $self->_SetSelectedRegion($Servlet);
    $self->SUPER::ViewTransactions($Servlet);
    return;
}

sub SearchTransactions {
    my $self      = shift;
    my ($Servlet) = @_;

    $self->_SetSelectedRegion($Servlet);
    return $self->SUPER::SearchTransactions($Servlet);
}

sub _SetSelectedRegion {
    my $self      = shift;
    my ($Servlet) = @_;
    my $Shop      = $Servlet->object;

    my ($PaymentMethod) = grep { $_->get('PaymentType')->alias eq 'AmazonPayments' } @{$Shop->get('PaymentMethods')};
    if ($PaymentMethod) {
        my $SelectedRegion = $PaymentMethod->get('AmazonRegion');
        my $LanguageCode = $SelectedRegion eq 'DE' ? AMAZON_DE_LANGUAGECODE : AMAZON_UK_LANGUAGECODE;
        my $LanguageID = GetInfoLanguagesByCode2($LanguageCode)->[0]->{'LanguageID'};

        my $RootObject = LoadRootObject();
        my $AdminUrl = $RootObject->get('AmazonPayments_AdminUrl', $LanguageID);
        $Servlet->vars('ADMIN_URL', $AdminUrl);
    }
}

1;
